#  Pyrofork - Telegram MTProto API Client Library for Python
#  Copyright (C) 2022-present Mayuri-Chan <https://github.com/Mayuri-Chan>
#
#  This file is part of Pyrofork.
#
#  Pyrofork is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrofork is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrofork.  If not, see <http://www.gnu.org/licenses/>.

import logging
from typing import Union, List

import pyrogram
from pyrogram import raw
from pyrogram import types

log = logging.getLogger(__name__)

class GetUserStories:
    async def get_user_stories(
        self: "pyrogram.Client",
        user_id: Union[int, str]
    ) -> List["types.Story"]:
        """Get all active stories from an user by using user identifiers.

        .. include:: /_includes/usable-by/users.rst

        Parameters:
            user_id (``int`` | ``str``):
                Unique identifier (int) or username (str) of the target user.
                For your personal story you can simply use "me" or "self".
                For a contact that exists in your Telegram address book you can use his phone number (str).

        Returns:
            List of :obj:`~pyrogram.types.Story`: A list of stories is returned.

        Example:
            .. code-block:: python

                # Get all active story (list of stories)
                await app.get_user_stories(user_id)

        Raises:
            ValueError: In case of invalid arguments.
        """

        peer = await self.resolve_peer(user_id)


        rpc = raw.functions.stories.GetUserStories(user_id=peer)

        r = await self.invoke(rpc, sleep_threshold=-1)

        return types.List([await types.Story._parse(self, story, user_id) for story in r.stories.stories])
